@@ -17,5 +17,8 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         self.stdout.write('Running cleanupregistration.')
-        RegistrationProfile.objects.delete_expired_users()
-        self.stdout.write('cleanupregistration completed.')
+        deleted_count = RegistrationProfile.objects.delete_expired_users()
+        if deleted_count == 0:
+            self.stdout.write('cleanupregistration completed. There is no user has to be deleted.')
+        else:
+            self.stdout.write('cleanupregistration completed. Deleted user count=%d' % deleted_count)
